<?xml version="1.0" ?><!DOCTYPE TS><TS language="nl_NL" version="2.0">
<context>
    <name>TestPlugin</name>
    <message>
        <location filename="../testplugin.cpp" line="121"/>
        <source>Close</source>
        <translation>Sluit</translation>
    </message>
    <message>
        <location filename="../testplugin.cpp" line="132"/>
        <source>Example Plugin Settings</source>
        <translation>Voorbeeldplugin-instellingen</translation>
    </message>
    <message>
        <location filename="../testplugin.cpp" line="160"/>
        <source>My first plugin action</source>
        <translation>Mijn eerste plugin-actie</translation>
    </message>
    <message>
        <location filename="../testplugin.cpp" line="175"/>
        <source>Hello</source>
        <translation>Hallo</translation>
    </message>
    <message>
        <location filename="../testplugin.cpp" line="175"/>
        <source>First plugin action works :-)</source>
        <translation>Eerste plugin-actie werkt :-)</translation>
    </message>
</context>
<context>
    <name>TestPlugin_Sidebar</name>
    <message>
        <location filename="../testplugin_sidebar.cpp" line="32"/>
        <location filename="../testplugin_sidebar.cpp" line="37"/>
        <source>Testing Sidebar</source>
        <translation>Testen van zijpaneel</translation>
    </message>
</context>
</TS>